@@ -34,7 +34,6 @@ import attr
 
 from hypothesis.errors import InvalidArgument, HypothesisDeprecationWarning
 from hypothesis.configuration import hypothesis_home_dir
-from hypothesis.internal.compat import PYPY
 from hypothesis.utils.conventions import UniqueIdentifier, not_set
 from hypothesis.utils.dynamicvariables import DynamicVariable
 
@@ -75,12 +74,12 @@ class settingsProperty(object):
 
     @property
     def __doc__(self):
+        description = all_settings[self.name].description
+        deprecation_message = all_settings[self.name].deprecation_message
         default = repr(getattr(settings.default, self.name)) if \
             self.show_default else '(dynamically calculated)'
-        return '\n'.join((
-            all_settings[self.name].description,
-            'default value: %s' % (default,)
-        ))
+        return '\n\n'.join([description, 'default value: %s' % (default,),
+                            (deprecation_message or '').strip()]).strip()
 
 
 default_variable = DynamicVariable(None)
@@ -266,8 +265,8 @@ class settings(settingsMeta('settings', (object,), {})):
         If this was explicitly set at settings instantiation then that
         value will be used (even if it was None). If not and the
         database_file setting is not None this will be lazily loaded as
-        an ExampleDatabase using that file the first time this property
-        is accessed on a particular thread.
+        an ExampleDatabase, using that file the first time that this
+        property is accessed on a particular thread.
 
         """
         if self._database is not_set and self.database_file is not None:
@@ -373,17 +372,6 @@ will terminate.
 """
 )
 
-settings.define_setting(
-    'max_mutations',
-    default=10,
-    description="""
-Hypothesis will try this many variations on a single example before moving on
-to an entirely fresh start. If you've got hard to satisfy properties raising
-this might help, but you probably shouldn't touch this dial unless you really
-know what you're doing.
-"""
-)
-
 settings.define_setting(
     'buffer_size',
     default=8 * 1024,
@@ -422,15 +410,12 @@ if it has not found many examples. This is a soft rather than a hard
 limit - Hypothesis won't e.g. interrupt execution of the called
 function to stop it. If this value is <= 0 then no timeout will be
 applied.
-
-Note: This setting is deprecated. In future Hypothesis will be removing the
-timeout feature.
 """,
     deprecation_message="""
-The timeout feature will go away in a future version of Hypothesis. To get
-the future behaviour set timeout=hypothesis.unlimited instead (which will
-remain valid for a further deprecation period after this setting has gone
-away).
+The timeout setting is deprecated and will be removed in a future version of
+Hypothesis. To get the future behaviour set ``timeout=hypothesis.unlimited``
+instead (which will remain valid for a further deprecation period after this
+setting has gone away).
 """,
     future_default=unlimited,
     validator=_validate_timeout
@@ -444,8 +429,8 @@ If this is True then hypothesis will run in deterministic mode
 where each falsification uses a random number generator that is seeded
 based on the hypothesis to falsify, which will be consistent across
 multiple runs. This has the advantage that it will eliminate any
-randomness from your tests, which may be preferable for some situations
-. It does have the disadvantage of making your tests less likely to
+randomness from your tests, which may be preferable for some situations.
+It does have the disadvantage of making your tests less likely to
 find novel breakages.
 """
 )
@@ -457,14 +442,14 @@ settings.define_setting(
 If set to True, anything that would cause Hypothesis to issue a warning will
 instead raise an error. Note that new warnings may be added at any time, so
 running with strict set to True means that new Hypothesis releases may validly
-break your code.
+break your code.  Note also that, as strict mode is itself deprecated,
+enabling it is now an error!
 
 You can enable this setting temporarily by setting the HYPOTHESIS_STRICT_MODE
 environment variable to the string 'true'.
 """,
     deprecation_message="""
 Strict mode is deprecated and will go away in a future version of Hypothesis.
-
 To get the same behaviour, use
 warnings.simplefilter('error', HypothesisDeprecationWarning).
 """,
@@ -479,7 +464,7 @@ settings.define_setting(
     ),
     show_default=False,
     description="""
-    database: An instance of hypothesis.database.ExampleDatabase that will be
+    An instance of hypothesis.database.ExampleDatabase that will be
 used to save examples to and load previous examples from. May be None
 in which case no storage will be used.
 """
@@ -616,16 +601,7 @@ attempting to actually execute your test.
 settings.define_setting(
     'suppress_health_check',
     default=[],
-    description="""A list of health checks to disable"""
-)
-
-settings.define_setting(
-    'report_statistics',
-    default=Statistics.interesting,
-    description=u"""
-If set to True, Hypothesis will run a preliminary health check before
-attempting to actually execute your test.
-"""
+    description="""A list of health checks to disable."""
 )
 
 settings.define_setting(
@@ -649,15 +625,15 @@ deadline and have not explicitly set a deadline yourself.
 
 settings.define_setting(
     'use_coverage',
-    default=not PYPY,
-    show_default=False,
+    default=True,
     description="""
 Whether to use coverage information to improve Hypothesis's ability to find
-bugs. You should generally leave this turned on unless your code performs
-poorly when run under coverage.
+bugs.
 
-Note: This is turned on by default except on pypy, where coverage performance
-is sufficiently poor as to make this unusable.
+You should generally leave this turned on unless your code performs
+poorly when run under coverage. If you turn it off, please file a bug report
+or add a comment to an existing one about the problem that prompted you to do
+so.
 """
 )
 
